{% extends 'bootstrap.html' %}

{% load propeller %}

{% block propeller_content %}

    <nav class="navbar navbar-inverse  pmd-navbar pmd-z-depth" role="navigation">
        <div class="container-fluid">
            <div class="navbar-header">
                <button type="button" class="pmd-navbar-toggle navbar-toggle" data-toggle="collapse" data-target="#navbar-collapse">
                    <span class="sr-only">Toggle navigation</span>
                    <span class="icon-bar"></span>
                    <span class="icon-bar"></span>
                    <span class="icon-bar"></span>
                </button>
                <a class="navbar-brand" href="#">django-propeller</a>
            </div>

            <div class="collapse navbar-collapse" id="navbar-collapse">
                <ul class="nav navbar-nav">
                    <li><a class="pmd-ripple-effect" href="{% url 'home' %}">Home</a></li>
                    <li><a class="pmd-ripple-effect" href="{% url 'buttons' %}">Buttons</a></li>
                    <li class="dropdown pmd-dropdown">
                        <a data-toggle="dropdown" class="pmd-ripple-effect dropdown-toggle" data-sidebar="true" href="javascript:void(0);">Forms<span class="caret"></span></a>
                        <ul class="dropdown-menu">
                            <li><a class="pmd-ripple-effect" href="{% url 'form_default' %}">Form</a></li>
                            <li><a class="pmd-ripple-effect" href="{% url 'formset_default' %}">Formset</a></li>
                            <li><a class="pmd-ripple-effect" href="{% url 'form_by_field' %}">Form by field</a></li>
                            <li><a class="pmd-ripple-effect" href="{% url 'form_horizontal' %}">Form horizontal</a></li>
                            <li><a class="pmd-ripple-effect" href="{% url 'form_inline' %}">Form inline</a></li>
                            <li><a class="pmd-ripple-effect" href="{% url 'form_with_files' %}">Form with files</a></li>
                        </ul>
                    </li>
                    <li><a class="pmd-ripple-effect" href="{% url 'pagination' %}">Pagination</a></li>
                    <li><a class="pmd-ripple-effect" href="{% url 'misc' %}">Miscellaneous</a></li>
                </ul>
            </div>
        </div>
    </nav>

    <div class="container">
        <h2>{% block title %}django-propeller{% endblock %}</h2>
        {% autoescape off %}{% propeller_messages %}{% endautoescape %}

        {% block content %}(no content){% endblock %}
    </div>

{% endblock %}
