<!DOCTYPE html>
{% load propeller staticfiles %}
<html{% if request.LANGUAGE_CODE %} lang="{{ request.LANGUAGE_CODE }}"{% endif %}>

<head>
    <meta charset="utf-8">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <title>{% block propeller_title %}django_propeller template title{% endblock %}</title>

    <!-- Bootstrap css-->
    {% propeller_css %}

    <!--Google Icon Font-->
    <link href="http://fonts.googleapis.com/icon?family=Material+Icons" rel="stylesheet">

    <!-- Propeller css -->
    <link href="{% static 'css/propeller.min.css' %}" rel="stylesheet">

    <!-- HTML5 Shim and Respond.js IE8 support of HTML5 elements and media queries -->
    <!-- WARNING: Respond.js doesn't work if you view the page via file:// -->
    <!--[if lt IE 9]>
    <script src="https://oss.maxcdn.com/libs/html5shiv/3.7.0/html5shiv.js"></script>
    <script src="https://oss.maxcdn.com/libs/respond.js/1.4.2/respond.min.js"></script>
    <![endif]-->
    {% if 'javascript_in_head'|propeller_setting %}
        {% propeller_javascript jquery=True %}
        <script type="text/javascript" src="{% static 'js/propeller.min.js' %}"></script>
    {% endif %}
    {% block propeller_extra_head %}{% endblock %}
</head>

<body>
{% block propeller_content %}django-propeller template content{% endblock %}
{% if not 'javascript_in_head'|propeller_setting %}
    {% propeller_javascript jquery=True %}
    <script type="text/javascript" src="{% static 'js/propeller.min.js' %}"></script>
{% endif %}
{% block propeller_extra_script %}{% endblock %}
</body>

</html>
