{% extends 'base.html' %}

{% load propeller %}

{% block title %}
    Forms
{% endblock %}

{% block content %}

    <form role="form" method="post">
        {% csrf_token %}
        {% propeller_form_errors form type='non_fields' %}
        {% propeller_field form.subject layout='horizontal' size='sm' %}
        {% propeller_field form.message placeholder='bonkers' %}
        {% buttons submit='OK' reset="Cancel" %}{% endbuttons %}
    </form>

{% endblock %}
