{% extends 'base.html' %}

{% load propeller %}

{% block title %}
    Forms
{% endblock %}

{% block content %}

    <form role="form" class="form-inline" method="post">
        {% csrf_token %}
        {% propeller_form form layout='inline' %}
        {% buttons submit='OK' reset='Cancel' layout='inline' %}{% endbuttons %}
    </form>

{% endblock %}
